@@ -53,6 +53,16 @@ class WiFiInstruction(BaseInstruction, ABC):
         'ieee80211ac=1\n'
     )
 
+    HOSTAPD_CONF_NO_PSK_TEMPLATE = (
+        'ssid={ssid}\n'
+        'interface={interface}\n'
+        'channel=1\n'
+        'driver=nl80211\n'
+        'hw_mode=g\n'
+        'ieee80211n=1\n'
+        'ieee80211ac=1\n'
+    )
+
     DNSMASQ_CONF_TEMPLATE = (
         'interface={interface}\n'
         'dhcp-range={start_ip},{stop_ip},24h\n'
@@ -150,9 +160,10 @@ class WiFiInstruction(BaseInstruction, ABC):
 
         log_file = open(self.HOSTAPD_LOG_FILE, 'w+')
 
+        conf_template = self.HOSTAPD_CONF_TEMPLATE if self.psk else self.HOSTAPD_CONF_NO_PSK_TEMPLATE
+
         with open(self.HOSTAPD_CONF_FILE, 'w') as conf_file:
-            conf = self.HOSTAPD_CONF_TEMPLATE.format(ssid=self.ssid, psk=self.psk,
-                                                     interface=settings.WIFI_INTERFACE)
+            conf = conf_template.format(ssid=self.ssid, psk=self.psk, interface=settings.WIFI_INTERFACE)
             conf_file.write(conf)
 
         subprocess.Popen(['hostapd', conf_file.name], stdout=log_file, stderr=subprocess.STDOUT)
@@ -472,6 +483,18 @@ class WiFiInstruction(BaseInstruction, ABC):
         except subprocess.CalledProcessError:
             raise IPConfigException('could not set host IP address')
 
+    def flush_ip_address(self):
+        self.logger.debug('flushing IP address')
+
+        cmd = 'ip addr flush {interface}'
+        cmd = cmd.format(interface=settings.WIFI_INTERFACE)
+
+        try:
+            subprocess.check_call(cmd, shell=True)
+
+        except subprocess.CalledProcessError:
+            raise IPConfigException('could not flush IP address')
+
     def flush_arp_cache(self):
         self.logger.debug('flushing ARP cache')
 
@@ -496,6 +519,7 @@ class WiFiInstruction(BaseInstruction, ABC):
             self.stop_hostapd()
         if self.is_dnsmasq_running():
             self.stop_dnsmasq()
+        self.flush_ip_address()
         self.flush_arp_cache()
 
     def tear_down_job(self):
